@@ -1,18 +1,18 @@
 package Dist::Zilla::Plugin::Pcore::Meta;
 
 use Moose;
-use P;
-use P::Devel::VCSInfo;
+use Pcore;
+use Pcore::Devel::VCSInfo;
 
 with qw[Dist::Zilla::Role::MetaProvider];
 
 has vcs => ( is => 'ro', isa => 'Object', lazy => 1, builder => '_build_vcs', init_arg => undef );
 
-no P;
+no Pcore;
 no Moose;
 
 sub _build_vcs ($self) {
-    return P::Devel::VCSInfo->new( { root => q[.] } );
+    return Pcore::Devel::VCSInfo->new( { root => q[.] } );
 }
 
 sub metadata ($self) {
