@@ -4,7 +4,7 @@ use Pcore qw[-class];
 use Term::ANSIColor qw[:constants];
 
 has action => ( is => 'ro', isa => Enum [qw[decompress compress obfuscate]], required => 1 );
-has path => ( is => 'ro', isa => InstanceOf ['Pcore::Util::File::Path'], required => 1 );
+has path => ( is => 'ro', isa => InstanceOf ['Pcore::Util::Path'], required => 1 );
 has is_realpath => ( is => 'lazy', isa => Bool );
 has in_buffer   => ( is => 'lazy', isa => ScalarRef, predicate => 1 );
 has decode      => ( is => 'ro',   isa => Bool, default => 0 );
@@ -15,7 +15,7 @@ has out_buffer  => ( is => 'lazy', isa => ScalarRef, init_arg => undef );
 has is_binary   => ( is => 'lazy', isa => Bool,      init_arg => undef );
 has was_changed => ( is => 'lazy', isa => Bool,      init_arg => undef );
 has severity    => ( is => 'rw',   isa => Int,       default  => 0, init_arg => undef );
-has severity_range => ( is => 'lazy', isa => Enum [ keys Pcore::Src::File->cfg->{SEVERITY_RANGE} ], init_arg => undef );
+has severity_range => ( is => 'lazy', isa => Enum [ keys Pcore::Src::File->cfg->{SEVERITY_RANGE}->%* ], init_arg => undef );
 
 has _can_write => ( is => 'rw', isa => Bool, default => 0, init_arg => undef );
 has _in_size  => ( is => 'lazy', isa => Int, init_arg => undef );
@@ -33,7 +33,7 @@ sub cfg ($self) {
 }
 
 sub detect_filetype ( $self, $path, $buffer_ref = undef ) {
-    $path = P->file->path($path);
+    $path = P->path($path);
 
     my $type;
 
@@ -80,7 +80,7 @@ sub detect_filetype ( $self, $path, $buffer_ref = undef ) {
 }
 
 sub BUILDARGS ( $self, $args ) {
-    $args->{path} = P->file->path( $args->{path} ) if !ref $args->{path};
+    $args->{path} = P->path( $args->{path} ) if !ref $args->{path};
 
     return $args;
 }
@@ -259,7 +259,7 @@ sub _build_out_buffer ($self) {
 }
 
 sub _build_severity_range ($self) {
-    for my $range ( reverse sort { Pcore::Src::File->cfg->{SEVERITY_RANGE}->{$a} <=> Pcore::Src::File->cfg->{SEVERITY_RANGE}->{$b} } keys Pcore::Src::File->cfg->{SEVERITY_RANGE} ) {
+    for my $range ( reverse sort { Pcore::Src::File->cfg->{SEVERITY_RANGE}->{$a} <=> Pcore::Src::File->cfg->{SEVERITY_RANGE}->{$b} } keys Pcore::Src::File->cfg->{SEVERITY_RANGE}->%* ) {
         if ( $self->severity >= Pcore::Src::File->cfg->{SEVERITY_RANGE}->{$range} ) {
             return $range;
         }
@@ -290,7 +290,7 @@ sub run ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 239                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 18, 239, 262         │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
