@@ -33,6 +33,10 @@ sub decompress ( $self, % ) {
 
     $perltidy_argv .= ' --logfile-gap=50' if $args{perl_verbose};
 
+    # temporary conver source to the utf8
+    # https://rt.cpan.org/Public/Bug/Display.html?id=32905
+    P->text->decode( $self->buffer );
+
     Perl::Tidy::perltidy(
         source      => $self->buffer,
         destination => $self->buffer,
@@ -42,6 +46,9 @@ sub decompress ( $self, % ) {
         argv        => $perltidy_argv,
     );
 
+    # convert source back to raw
+    P->text->encode_utf8( $self->buffer );
+
     my $error_log;
 
     if ($err) {
@@ -100,21 +107,21 @@ sub decompress ( $self, % ) {
 
             # create table
             # sorting violations by descending severity, ascending first line then by policy text
-            for my $v ( sort { $violations->{$a}->{severity} != $violations->{$b}->{severity} ? $violations->{$b}->{severity} <=> $violations->{$a}->{severity} : $violations->{$a}->{first_line} != $violations->{$b}->{first_line} ? $violations->{$a}->{first_line} <=> $violations->{$b}->{first_line} : $a cmp $b } keys $violations ) {
+            for my $v ( sort { $violations->{$a}->{severity} != $violations->{$b}->{severity} ? $violations->{$b}->{severity} <=> $violations->{$a}->{severity} : $violations->{$a}->{first_line} != $violations->{$b}->{first_line} ? $violations->{$a}->{first_line} <=> $violations->{$b}->{first_line} : $a cmp $b } keys $violations->%* ) {
                 my $policy = $v;
 
-                if ( keys $violations->{$v}->{desc} > 1 ) {    # multiple violations with different descriptions
+                if ( keys $violations->{$v}->{desc}->%* > 1 ) {    # multiple violations with different descriptions
                     $t->add_row( $violations->{$v}->{severity}, q[], $policy );
 
                     # sorting descriptions by ascending first line number, then by description text
-                    for my $desc ( sort { $violations->{$v}->{desc}->{$a}->{line}->[0] != $violations->{$v}->{desc}->{$b}->{line}->[0] ? $violations->{$v}->{desc}->{$a}->{line}->[0] <=> $violations->{$v}->{desc}->{$b}->{line}->[0] : $violations->{$v}->{desc}->{$a}->{text} cmp $violations->{$v}->{desc}->{$b}->{text} } keys $violations->{$v}->{desc} ) {
+                    for my $desc ( sort { $violations->{$v}->{desc}->{$a}->{line}->[0] != $violations->{$v}->{desc}->{$b}->{line}->[0] ? $violations->{$v}->{desc}->{$a}->{line}->[0] <=> $violations->{$v}->{desc}->{$b}->{line}->[0] : $violations->{$v}->{desc}->{$a}->{text} cmp $violations->{$v}->{desc}->{$b}->{text} } keys $violations->{$v}->{desc}->%* ) {
                         $t->add_row( q[], join( q[, ], sort { $a <=> $b } $violations->{$v}->{desc}->{$desc}->{line}->@* ), qq[* $violations->{$v}->{desc}->{$desc}->{text}] );
                     }
                 }
-                else {                                         # single violation
+                else {                                             # single violation
                     $policy .= qq[ - $violations->{$v}->{desc}->{[keys $violations->{$v}->{desc}->%*]->[0]}->{text}];
 
-                    $t->add_row( $violations->{$v}->{severity}, join( q[, ], sort { $a <=> $b } keys $violations->{$v}->{line} ), $policy );
+                    $t->add_row( $violations->{$v}->{severity}, join( q[, ], sort { $a <=> $b } keys $violations->{$v}->{line}->%* ), $policy );
                 }
 
                 # add diagnostic
@@ -196,7 +203,7 @@ sub compress ( $self, % ) {
         }
     }
 
-    $self->buffer->$* = $cache->{$key} . $data_section;                ## no critic qw(Variables::RequireLocalizedPunctuationVars)
+    $self->buffer->$* = $cache->{$key} . $data_section;                ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
     return 0;
 }
@@ -230,7 +237,7 @@ sub _get_perlcritic_profile_name ( $self, $profile ) {
     if ( $profile eq '1' ) {
         $profile = 0;
 
-        for my $name ( keys $self->src_cfg->{PERLCRITIC} ) {
+        for my $name ( keys $self->src_cfg->{PERLCRITIC}->%* ) {
             next if !exists $self->src_cfg->{PERLCRITIC}->{$name}->{__autodetect__};
 
             if ( $self->src_cfg->{PERLCRITIC}->{$name}->{__autodetect__}->( $self->buffer->$* ) ) {
@@ -266,7 +273,7 @@ sub _get_perlcritic_object ( $self, $name ) {
         my $profile = $get_profile->($name);
 
         # convert profile to Perl::Critic format
-        for my $policy ( keys $profile ) {
+        for my $policy ( keys $profile->%* ) {
             if ( !$profile->{$policy} ) {
                 delete $profile->{$policy};
 
@@ -323,7 +330,7 @@ sub _format_sub_signature ( $sub_name, $sub_sign ) {
 
             $sign = qq[$var =];
 
-            $sign .= qq[ $val] if $val;
+            $sign .= qq[ $val] if $val ne q[];
         }
 
         push @formatted_signs, $sign;
@@ -339,7 +346,7 @@ sub _format_sub_signature ( $sub_name, $sub_sign ) {
 }
 
 sub cut_log ($self) {
-    $self->buffer->$* =~ s/^## -----SOURCE FILTER LOG BEGIN-----.*?## -----SOURCE FILTER LOG END-----\n?//sm;    ## no critic qw(RegularExpressions::ProhibitComplexRegexes)
+    $self->buffer->$* =~ s/^## -----SOURCE FILTER LOG BEGIN-----.*?## -----SOURCE FILTER LOG END-----\n?//sm;    ## no critic qw[RegularExpressions::ProhibitComplexRegexes]
 
     P->text->rcut_all( $self->buffer->$* );
 
@@ -355,9 +362,12 @@ sub cut_log ($self) {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 8                    │ Subroutines::ProhibitExcessComplexity - Subroutine "decompress" with high complexity score (24)                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 154                  │ Miscellanea::ProhibitTies - Tied variable used                                                                 │
+## │    3 │ 110, 113, 117, 124,  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │      │ 240, 276             │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 103                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
+## │    2 │ 161                  │ Miscellanea::ProhibitTies - Tied variable used                                                                 │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    1 │ 110                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
