@@ -1,9 +1,9 @@
 package Pcore::Util::Date;
 
 use Pcore;
-use HTTP::Date();
-use Time::Zone();
-use Time::Moment();
+use HTTP::Date qw[];
+use Time::Zone qw[];
+use Time::Moment qw[];
 
 no Pcore;
 
