@@ -54,15 +54,15 @@ sub daemonize {
     P->EV->throw('CORE#DAEMONIZE');
 
     if ( !$MSWIN ) {
-        fork && exit 0;    ## no critic qw(InputOutput::RequireCheckedSyscalls)
+        fork && exit 0;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
 
         open STDIN, '+<', '/dev/null' or die;
         open STDOUT, '>&STDIN' or die;
         open STDERR, '>&STDIN' or die;
 
-        open $STDIN, '+<', '/dev/null' or die;    ## no critic qw(InputOutput::RequireBriefOpen)
-        open $STDOUT, '>&STDIN' or die;           ## no critic qw(InputOutput::RequireBriefOpen)
-        open $STDERR, '>&STDIN' or die;           ## no critic qw(InputOutput::RequireBriefOpen)
+        open $STDIN, '+<', '/dev/null' or die;    ## no critic qw[InputOutput::RequireBriefOpen]
+        open $STDOUT, '>&STDIN' or die;           ## no critic qw[InputOutput::RequireBriefOpen]
+        open $STDERR, '>&STDIN' or die;           ## no critic qw[InputOutput::RequireBriefOpen]
 
         POSIX::setsid() or die qq[Can't set sid: $!];
 
